dag_cbor.decoding.err
=====================

.. automodule:: dag_cbor.decoding.err

CBORDecodingError
-----------------

.. autoclass:: dag_cbor.decoding.err.CBORDecodingError
    :show-inheritance:
    :members:

DAGCBORDecodingError
--------------------

.. autoclass:: dag_cbor.decoding.err.DAGCBORDecodingError
    :show-inheritance:
    :members:
